# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: LT4FootswitchModeStatus.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'LT4FootswitchModeStatus.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dLT4FootswitchModeStatus.proto\"P\n\x17LT4FootswitchModeStatus\x12\x35\n\x0b\x63urrentMode\x18\x01 \x02(\x0e\x32\r.LT4FtswModes:\x11LT4_FTSW_MODE_OFF*m\n\x0cLT4FtswModes\x12\x15\n\x11LT4_FTSW_MODE_OFF\x10\x00\x12\x17\n\x13LT4_FTSW_MODE_BANK1\x10\x01\x12\x17\n\x13LT4_FTSW_MODE_BANK2\x10\x02\x12\x14\n\x10LT4_FTSW_MODE_FX\x10\x03')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'LT4FootswitchModeStatus_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_LT4FTSWMODES']._serialized_start=115
  _globals['_LT4FTSWMODES']._serialized_end=224
  _globals['_LT4FOOTSWITCHMODESTATUS']._serialized_start=33
  _globals['_LT4FOOTSWITCHMODESTATUS']._serialized_end=113
# @@protoc_insertion_point(module_scope)
