# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: IndexButton.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'IndexButton.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11IndexButton.proto\"\xa0\x01\n\x0bIndexButton\x12\r\n\x05index\x18\x01 \x02(\x05\x12!\n\x05\x65vent\x18\x02 \x02(\x0e\x32\x12.IndexButton.Event\x12\x14\n\x0ctimestamp_ms\x18\x03 \x01(\r\"I\n\x05\x45vent\x12\x0f\n\x0b\x45VENT_ERROR\x10\x00\x12\x0f\n\x0b\x42UTTON_DOWN\x10\x01\x12\r\n\tBUTTON_UP\x10\x02\x12\x0f\n\x0b\x42UTTON_HELD\x10\x03')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'IndexButton_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_INDEXBUTTON']._serialized_start=22
  _globals['_INDEXBUTTON']._serialized_end=182
  _globals['_INDEXBUTTON_EVENT']._serialized_start=109
  _globals['_INDEXBUTTON_EVENT']._serialized_end=182
# @@protoc_insertion_point(module_scope)
