# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: FenderMessageLT.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'FenderMessageLT.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .IndexPot_pb2 import IndexPot as IndexPot__pb2
import IndexButton_pb2 as IndexButton__pb2
import IndexEncoder_pb2 as IndexEncoder__pb2
import LoadPreset_pb2 as LoadPreset__pb2
import PresetJSONMessageRequest_LT_pb2 as PresetJSONMessageRequest__LT__pb2
import PresetJSONMessage_pb2 as PresetJSONMessage__pb2
import ProcessorUtilizationRequest_pb2 as ProcessorUtilizationRequest__pb2
import ProcessorUtilization_pb2 as ProcessorUtilization__pb2
import FrameBufferMessageRequest_pb2 as FrameBufferMessageRequest__pb2
import FrameBufferMessage_pb2 as FrameBufferMessage__pb2
import ActiveDisplay_pb2 as ActiveDisplay__pb2
import MemoryUsageStatus_pb2 as MemoryUsageStatus__pb2
import MemoryUsageRequest_pb2 as MemoryUsageRequest__pb2
import LoopbackTest_pb2 as LoopbackTest__pb2
import CurrentLoadedPresetIndexStatus_pb2 as CurrentLoadedPresetIndexStatus__pb2
import SetDspUnitParameter_pb2 as SetDspUnitParameter__pb2
import AudioStatus_pb2 as AudioStatus__pb2
import SetDspUnitParameterStatus_pb2 as SetDspUnitParameterStatus__pb2
import DspUnitParameterStatus_pb2 as DspUnitParameterStatus__pb2
import ReplaceNode_pb2 as ReplaceNode__pb2
import ReplaceNodeStatus_pb2 as ReplaceNodeStatus__pb2
import ProductIdentificationRequest_pb2 as ProductIdentificationRequest__pb2
import ProductIdentificationStatus_pb2 as ProductIdentificationStatus__pb2
import FirmwareVersionRequest_pb2 as FirmwareVersionRequest__pb2
import FirmwareVersionStatus_pb2 as FirmwareVersionStatus__pb2
import CurrentPresetRequest_pb2 as CurrentPresetRequest__pb2
import CurrentPresetSet_pb2 as CurrentPresetSet__pb2
import CurrentPresetStatus_pb2 as CurrentPresetStatus__pb2
import RetrievePreset_pb2 as RetrievePreset__pb2
import UsbGainRequest_pb2 as UsbGainRequest__pb2
import UsbGainStatus_pb2 as UsbGainStatus__pb2
import UsbGainSet_pb2 as UsbGainSet__pb2
import LineOutGainRequest_pb2 as LineOutGainRequest__pb2
import LineOutGainStatus_pb2 as LineOutGainStatus__pb2
import LineOutGainSet_pb2 as LineOutGainSet__pb2
import QASlotsRequest_pb2 as QASlotsRequest__pb2
import QASlotsStatus_pb2 as QASlotsStatus__pb2
import QASlotsSet_pb2 as QASlotsSet__pb2
import PresetSavedStatus_pb2 as PresetSavedStatus__pb2
import ModalStatusMessage_pb2 as ModalStatusMessage__pb2
import UnsupportedMessageStatus_pb2 as UnsupportedMessageStatus__pb2
import ClearPreset_pb2 as ClearPreset__pb2
import ClearPresetStatus_pb2 as ClearPresetStatus__pb2
import SaveCurrentPreset_pb2 as SaveCurrentPreset__pb2
import SaveCurrentPresetTo_pb2 as SaveCurrentPresetTo__pb2
import SavePresetAs_pb2 as SavePresetAs__pb2
import NewPresetSavedStatus_pb2 as NewPresetSavedStatus__pb2
import RenamePresetAt_pb2 as RenamePresetAt__pb2
import AuditionPreset_pb2 as AuditionPreset__pb2
import AuditionPresetStatus_pb2 as AuditionPresetStatus__pb2
import ExitAuditionPreset_pb2 as ExitAuditionPreset__pb2
import ExitAuditionPresetStatus_pb2 as ExitAuditionPresetStatus__pb2
import AuditionStateRequest_pb2 as AuditionStateRequest__pb2
import AuditionStateStatus_pb2 as AuditionStateStatus__pb2
import LT4FootswitchModeRequest_pb2 as LT4FootswitchModeRequest__pb2
import LT4FootswitchModeStatus_pb2 as LT4FootswitchModeStatus__pb2
import Heartbeat_pb2 as Heartbeat__pb2
import ShiftPreset_pb2 as ShiftPreset__pb2
import ShiftPresetStatus_pb2 as ShiftPresetStatus__pb2
import SwapPreset_pb2 as SwapPreset__pb2
import SwapPresetStatus_pb2 as SwapPresetStatus__pb2
import ConnectionStatus_pb2 as ConnectionStatus__pb2
import ConnectionStatusRequest_pb2 as ConnectionStatusRequest__pb2
import LoadPreset_TestSuite_pb2 as LoadPreset__TestSuite__pb2
import CurrentLoadedPresetIndexBypassStatus_pb2 as CurrentLoadedPresetIndexBypassStatus__pb2
import CurrentDisplayedPresetIndexStatus_pb2 as CurrentDisplayedPresetIndexStatus__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15\x46\x65nderMessageLT.proto\x1a\x0eIndexPot.proto\x1a\x11IndexButton.proto\x1a\x12IndexEncoder.proto\x1a\x10LoadPreset.proto\x1a!PresetJSONMessageRequest_LT.proto\x1a\x17PresetJSONMessage.proto\x1a!ProcessorUtilizationRequest.proto\x1a\x1aProcessorUtilization.proto\x1a\x1f\x46rameBufferMessageRequest.proto\x1a\x18\x46rameBufferMessage.proto\x1a\x13\x41\x63tiveDisplay.proto\x1a\x17MemoryUsageStatus.proto\x1a\x18MemoryUsageRequest.proto\x1a\x12LoopbackTest.proto\x1a$CurrentLoadedPresetIndexStatus.proto\x1a\x19SetDspUnitParameter.proto\x1a\x11\x41udioStatus.proto\x1a\x1fSetDspUnitParameterStatus.proto\x1a\x1c\x44spUnitParameterStatus.proto\x1a\x11ReplaceNode.proto\x1a\x17ReplaceNodeStatus.proto\x1a\"ProductIdentificationRequest.proto\x1a!ProductIdentificationStatus.proto\x1a\x1c\x46irmwareVersionRequest.proto\x1a\x1b\x46irmwareVersionStatus.proto\x1a\x1a\x43urrentPresetRequest.proto\x1a\x16\x43urrentPresetSet.proto\x1a\x19\x43urrentPresetStatus.proto\x1a\x14RetrievePreset.proto\x1a\x14UsbGainRequest.proto\x1a\x13UsbGainStatus.proto\x1a\x10UsbGainSet.proto\x1a\x18LineOutGainRequest.proto\x1a\x17LineOutGainStatus.proto\x1a\x14LineOutGainSet.proto\x1a\x14QASlotsRequest.proto\x1a\x13QASlotsStatus.proto\x1a\x10QASlotsSet.proto\x1a\x17PresetSavedStatus.proto\x1a\x18ModalStatusMessage.proto\x1a\x1eUnsupportedMessageStatus.proto\x1a\x11\x43learPreset.proto\x1a\x17\x43learPresetStatus.proto\x1a\x17SaveCurrentPreset.proto\x1a\x19SaveCurrentPresetTo.proto\x1a\x12SavePresetAs.proto\x1a\x1aNewPresetSavedStatus.proto\x1a\x14RenamePresetAt.proto\x1a\x14\x41uditionPreset.proto\x1a\x1a\x41uditionPresetStatus.proto\x1a\x18\x45xitAuditionPreset.proto\x1a\x1e\x45xitAuditionPresetStatus.proto\x1a\x1a\x41uditionStateRequest.proto\x1a\x19\x41uditionStateStatus.proto\x1a\x1eLT4FootswitchModeRequest.proto\x1a\x1dLT4FootswitchModeStatus.proto\x1a\x0fHeartbeat.proto\x1a\x11ShiftPreset.proto\x1a\x17ShiftPresetStatus.proto\x1a\x10SwapPreset.proto\x1a\x16SwapPresetStatus.proto\x1a\x16\x43onnectionStatus.proto\x1a\x1d\x43onnectionStatusRequest.proto\x1a\x1aLoadPreset_TestSuite.proto\x1a*CurrentLoadedPresetIndexBypassStatus.proto\x1a\'CurrentDisplayedPresetIndexStatus.proto\"\xf7\x1a\n\x0f\x46\x65nderMessageLT\x12\x30\n\x0cresponseType\x18\x01 \x02(\x0e\x32\r.ResponseType:\x0bUNSOLICITED\x12\x1d\n\x08indexPot\x18\x02 \x01(\x0b\x32\t.IndexPotH\x00\x12#\n\x0bindexButton\x18\x03 \x01(\x0b\x32\x0c.IndexButtonH\x00\x12%\n\x0cindexEncoder\x18\x04 \x01(\x0b\x32\r.IndexEncoderH\x00\x12\'\n\ractiveDisplay\x18\x05 \x01(\x0b\x32\x0e.ActiveDisplayH\x00\x12\x43\n\x1bprocessorUtilizationRequest\x18\x06 \x01(\x0b\x32\x1c.ProcessorUtilizationRequestH\x00\x12\x35\n\x14processorUtilization\x18\x07 \x01(\x0b\x32\x15.ProcessorUtilizationH\x00\x12\x31\n\x12memoryUsageRequest\x18\x08 \x01(\x0b\x32\x13.MemoryUsageRequestH\x00\x12/\n\x11memoryUsageStatus\x18\t \x01(\x0b\x32\x12.MemoryUsageStatusH\x00\x12\x43\n\x1bpresetJSONMessageRequest_LT\x18\n \x01(\x0b\x32\x1c.PresetJSONMessageRequest_LTH\x00\x12?\n\x19\x66rameBufferMessageRequest\x18\x0b \x01(\x0b\x32\x1a.FrameBufferMessageRequestH\x00\x12\x31\n\x12\x66rameBufferMessage\x18\x0c \x01(\x0b\x32\x13.FrameBufferMessageH\x00\x12=\n\x18lt4FootswitchModeRequest\x18\r \x01(\x0b\x32\x19.LT4FootswitchModeRequestH\x00\x12;\n\x17lt4FootswitchModeStatus\x18\x0e \x01(\x0b\x32\x18.LT4FootswitchModeStatusH\x00\x12\x35\n\x14loadPreset_TestSuite\x18\x0f \x01(\x0b\x32\x15.LoadPreset_TestSuiteH\x00\x12%\n\x0cloopbackTest\x18\x1e \x01(\x0b\x32\r.LoopbackTestH\x00\x12/\n\x11presetJSONMessage\x18\x1f \x01(\x0b\x32\x12.PresetJSONMessageH\x00\x12\x33\n\x13\x63urrentPresetStatus\x18  \x01(\x0b\x32\x14.CurrentPresetStatusH\x00\x12!\n\nloadPreset\x18! \x01(\x0b\x32\x0b.LoadPresetH\x00\x12\x33\n\x13setDspUnitParameter\x18\" \x01(\x0b\x32\x14.SetDspUnitParameterH\x00\x12?\n\x19setDspUnitParameterStatus\x18# \x01(\x0b\x32\x1a.SetDspUnitParameterStatusH\x00\x12\x39\n\x16\x64spUnitParameterStatus\x18$ \x01(\x0b\x32\x17.DspUnitParameterStatusH\x00\x12I\n\x1e\x63urrentLoadedPresetIndexStatus\x18% \x01(\x0b\x32\x1f.CurrentLoadedPresetIndexStatusH\x00\x12\x31\n\x12presetEditedStatus\x18& \x01(\x0b\x32\x13.PresetEditedStatusH\x00\x12#\n\x0breplaceNode\x18\' \x01(\x0b\x32\x0c.ReplaceNodeH\x00\x12/\n\x11replaceNodeStatus\x18( \x01(\x0b\x32\x12.ReplaceNodeStatusH\x00\x12#\n\x0bshiftPreset\x18) \x01(\x0b\x32\x0c.ShiftPresetH\x00\x12/\n\x11shiftPresetStatus\x18* \x01(\x0b\x32\x12.ShiftPresetStatusH\x00\x12!\n\nswapPreset\x18+ \x01(\x0b\x32\x0b.SwapPresetH\x00\x12-\n\x10swapPresetStatus\x18, \x01(\x0b\x32\x11.SwapPresetStatusH\x00\x12-\n\x10\x63urrentPresetSet\x18- \x01(\x0b\x32\x11.CurrentPresetSetH\x00\x12U\n$currentLoadedPresetIndexBypassStatus\x18. \x01(\x0b\x32%.CurrentLoadedPresetIndexBypassStatusH\x00\x12O\n!currentDisplayedPresetIndexStatus\x18/ \x01(\x0b\x32\".CurrentDisplayedPresetIndexStatusH\x00\x12/\n\x11presetSavedStatus\x18\x32 \x01(\x0b\x32\x12.PresetSavedStatusH\x00\x12#\n\x0b\x63learPreset\x18\x33 \x01(\x0b\x32\x0c.ClearPresetH\x00\x12/\n\x11\x63learPresetStatus\x18\x34 \x01(\x0b\x32\x12.ClearPresetStatusH\x00\x12/\n\x11saveCurrentPreset\x18\x35 \x01(\x0b\x32\x12.SaveCurrentPresetH\x00\x12\x33\n\x13saveCurrentPresetTo\x18\x36 \x01(\x0b\x32\x14.SaveCurrentPresetToH\x00\x12%\n\x0csavePresetAs\x18\x37 \x01(\x0b\x32\r.SavePresetAsH\x00\x12\x35\n\x14newPresetSavedStatus\x18\x38 \x01(\x0b\x32\x15.NewPresetSavedStatusH\x00\x12)\n\x0erenamePresetAt\x18\x39 \x01(\x0b\x32\x0f.RenamePresetAtH\x00\x12)\n\x0e\x61uditionPreset\x18: \x01(\x0b\x32\x0f.AuditionPresetH\x00\x12\x35\n\x14\x61uditionPresetStatus\x18; \x01(\x0b\x32\x15.AuditionPresetStatusH\x00\x12\x31\n\x12\x65xitAuditionPreset\x18< \x01(\x0b\x32\x13.ExitAuditionPresetH\x00\x12=\n\x18\x65xitAuditionPresetStatus\x18= \x01(\x0b\x32\x19.ExitAuditionPresetStatusH\x00\x12\x35\n\x14\x61uditionStateRequest\x18> \x01(\x0b\x32\x15.AuditionStateRequestH\x00\x12\x33\n\x13\x61uditionStateStatus\x18? \x01(\x0b\x32\x14.AuditionStateStatusH\x00\x12\x43\n\x1bproductIdentificationStatus\x18\x64 \x01(\x0b\x32\x1c.ProductIdentificationStatusH\x00\x12\x45\n\x1cproductIdentificationRequest\x18\x65 \x01(\x0b\x32\x1d.ProductIdentificationRequestH\x00\x12\x39\n\x16\x66irmwareVersionRequest\x18\x66 \x01(\x0b\x32\x17.FirmwareVersionRequestH\x00\x12\x37\n\x15\x66irmwareVersionStatus\x18g \x01(\x0b\x32\x16.FirmwareVersionStatusH\x00\x12\x35\n\x14\x63urrentPresetRequest\x18h \x01(\x0b\x32\x15.CurrentPresetRequestH\x00\x12)\n\x0eretrievePreset\x18i \x01(\x0b\x32\x0f.RetrievePresetH\x00\x12)\n\x0eusbGainRequest\x18j \x01(\x0b\x32\x0f.UsbGainRequestH\x00\x12\'\n\rusbGainStatus\x18k \x01(\x0b\x32\x0e.UsbGainStatusH\x00\x12)\n\x0eqASlotsRequest\x18l \x01(\x0b\x32\x0f.QASlotsRequestH\x00\x12\'\n\rqASlotsStatus\x18m \x01(\x0b\x32\x0e.QASlotsStatusH\x00\x12\x31\n\x12lineOutGainRequest\x18n \x01(\x0b\x32\x13.LineOutGainRequestH\x00\x12/\n\x11lineOutGainStatus\x18o \x01(\x0b\x32\x12.LineOutGainStatusH\x00\x12\x31\n\x12modalStatusMessage\x18q \x01(\x0b\x32\x13.ModalStatusMessageH\x00\x12!\n\nusbGainSet\x18r \x01(\x0b\x32\x0b.UsbGainSetH\x00\x12)\n\x0elineOutGainSet\x18s \x01(\x0b\x32\x0f.LineOutGainSetH\x00\x12!\n\nqASlotsSet\x18t \x01(\x0b\x32\x0b.QASlotsSetH\x00\x12>\n\x18unsupportedMessageStatus\x18\xc8\x01 \x01(\x0b\x32\x19.UnsupportedMessageStatusH\x00\x12 \n\theartbeat\x18\xc9\x01 \x01(\x0b\x32\n.HeartbeatH\x00\x12<\n\x17\x63onnectionStatusRequest\x18\xca\x01 \x01(\x0b\x32\x18.ConnectionStatusRequestH\x00\x12.\n\x10\x63onnectionStatus\x18\xcb\x01 \x01(\x0b\x32\x11.ConnectionStatusH\x00\x42\x06\n\x04type*B\n\x0cResponseType\x12\x0f\n\x0bUNSOLICITED\x10\x00\x12\x10\n\x0cNOT_LAST_ACK\x10\x01\x12\x0f\n\x0bIS_LAST_ACK\x10\x02')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'FenderMessageLT_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_RESPONSETYPE']._serialized_start=5185
  _globals['_RESPONSETYPE']._serialized_end=5251
  _globals['_FENDERMESSAGELT']._serialized_start=1736
  _globals['_FENDERMESSAGELT']._serialized_end=5183
# @@protoc_insertion_point(module_scope)
