# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ModalStatusMessage.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ModalStatusMessage.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18ModalStatusMessage.proto\"P\n\x12ModalStatusMessage\x12\x1e\n\x07\x63ontext\x18\x01 \x02(\x0e\x32\r.ModalContext\x12\x1a\n\x05state\x18\x02 \x02(\x0e\x32\x0b.ModalState*\xf3\x01\n\x0cModalContext\x12\x0e\n\nSYNC_BEGIN\x10\x00\x12\x0c\n\x08SYNC_END\x10\x01\x12\x10\n\x0c\x42\x41\x43KUP_BEGIN\x10\x02\x12\x0e\n\nBACKUP_END\x10\x03\x12\x11\n\rRESTORE_BEGIN\x10\x04\x12\x0f\n\x0bRESTORE_END\x10\x05\x12\x10\n\x0cTUNER_ENABLE\x10\x06\x12\x11\n\rTUNER_DISABLE\x10\x07\x12\x19\n\x15\x46\x41\x43TORY_RESTORE_BEGIN\x10\x08\x12\x17\n\x13\x46\x41\x43TORY_RESTORE_END\x10\t\x12\x13\n\x0fTONE_BUSY_BEGIN\x10\n\x12\x11\n\rTONE_BUSY_END\x10\x0b*\x1e\n\nModalState\x12\x06\n\x02OK\x10\x00\x12\x08\n\x04\x46\x41IL\x10\x01')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ModalStatusMessage_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_MODALCONTEXT']._serialized_start=111
  _globals['_MODALCONTEXT']._serialized_end=354
  _globals['_MODALSTATE']._serialized_start=356
  _globals['_MODALSTATE']._serialized_end=386
  _globals['_MODALSTATUSMESSAGE']._serialized_start=28
  _globals['_MODALSTATUSMESSAGE']._serialized_end=108
# @@protoc_insertion_point(module_scope)
