# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: DspUnitParameterStatus.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'DspUnitParameterStatus.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x44spUnitParameterStatus.proto\"\xae\x01\n\x16\x44spUnitParameterStatus\x12\x0e\n\x06nodeId\x18\x01 \x02(\t\x12\x13\n\x0bparameterId\x18\x02 \x02(\t\x12\x18\n\x0e\x66loatParameter\x18\x03 \x01(\x02H\x00\x12\x19\n\x0fstringParameter\x18\x04 \x01(\tH\x00\x12\x19\n\x0fsint32Parameter\x18\x05 \x01(\x11H\x00\x12\x17\n\rboolParameter\x18\x06 \x01(\x08H\x00\x42\x06\n\x04type')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'DspUnitParameterStatus_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_DSPUNITPARAMETERSTATUS']._serialized_start=33
  _globals['_DSPUNITPARAMETERSTATUS']._serialized_end=207
# @@protoc_insertion_point(module_scope)
