# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: UnsupportedMessageStatus.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'UnsupportedMessageStatus.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1eUnsupportedMessageStatus.proto\"6\n\x18UnsupportedMessageStatus\x12\x1a\n\x06status\x18\x01 \x02(\x0e\x32\n.ErrorType*\x8a\x01\n\tErrorType\x12\x0f\n\x0bUNSUPPORTED\x10\x00\x12\n\n\x06\x46\x41ILED\x10\x01\x12\x11\n\rINVALID_PARAM\x10\x02\x12\x13\n\x0fINVALID_NODE_ID\x10\x03\x12\x17\n\x13PARAM_OUT_OF_BOUNDS\x10\x04\x12\x1f\n\x1b\x46\x41\x43TORY_RESTORE_IN_PROGRESS\x10\x05')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'UnsupportedMessageStatus_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_ERRORTYPE']._serialized_start=91
  _globals['_ERRORTYPE']._serialized_end=229
  _globals['_UNSUPPORTEDMESSAGESTATUS']._serialized_start=34
  _globals['_UNSUPPORTEDMESSAGESTATUS']._serialized_end=88
# @@protoc_insertion_point(module_scope)
